#include "led_controller.h"
#include "config.h"

LEDController::LEDController(Adafruit_MCP23X17* mcp1, Adafruit_MCP23X17* mcp2) {
  this->mcp1 = mcp1;
  this->mcp2 = mcp2;
  
  // Initialisiere alle LED-Zustände als AUS
  for(int i = 0; i < NUM_LEDS; i++) {
    ledStates[i] = false;
  }
}

void LEDController::init() {
  // Konfiguriere alle LED-Pins als Ausgänge
  // MCP1: LEDs 0-15 (Port A und B)
  // Port A = Pins 0-7, Port B = Pins 8-15
  for(int i = 0; i < 16; i++) {
    mcp1->pinMode(i, OUTPUT);
    mcp1->digitalWrite(i, LOW); // LEDs initial ausschalten
  }
  
  // MCP2: LEDs 16-19 (Port A, Pins 4-7)
  // Pins 0-3 sind für Buttons reserviert, LEDs nutzen Pins 4-7
  for(int i = 4; i < 8; i++) {
    mcp2->pinMode(i, OUTPUT);
    mcp2->digitalWrite(i, LOW); // LEDs initial ausschalten
  }
  
  Serial.println("LED Controller initialisiert - 20 LEDs konfiguriert");
}

void LEDController::setLED(uint8_t ledIndex, bool state) {
  if(ledIndex >= NUM_LEDS) return;
  
  ledStates[ledIndex] = state;
  
  // Aktualisiere Hardware sofort
  if(ledIndex < 16) {
    // LEDs 0-15 auf MCP1
    mcp1->digitalWrite(ledIndex, state ? HIGH : LOW);
  } else {
    // LEDs 16-19 auf MCP2 (Pins 4-7)
    mcp2->digitalWrite((ledIndex - 16) + 4, state ? HIGH : LOW);
  }
}

void LEDController::toggleLED(uint8_t ledIndex) {
  if(ledIndex >= NUM_LEDS) return;
  setLED(ledIndex, !ledStates[ledIndex]);
}

bool LEDController::getLEDState(uint8_t ledIndex) {
  if(ledIndex >= NUM_LEDS) return false;
  return ledStates[ledIndex];
}

void LEDController::updateHardware() {
  // Aktualisiere alle LED-Zustände in der Hardware
  // Diese Funktion kann aufgerufen werden, um sicherzustellen,
  // dass alle LEDs den gewünschten Zustand haben
  
  for(int i = 0; i < NUM_LEDS; i++) {
    if(i < 16) {
      // LEDs 0-15 auf MCP1
      mcp1->digitalWrite(i, ledStates[i] ? HIGH : LOW);
    } else {
      // LEDs 16-19 auf MCP2 (Pins 4-7)
      mcp2->digitalWrite((i - 16) + 4, ledStates[i] ? HIGH : LOW);
    }
  }
}
